[coreboot-gerrit] Change in ...coreboot[master]: mb/google/octopus: Enable mode change as wake source from S3/S0ix

Furquan Shaikh (Code Review) gerrit at coreboot.org
Sun Dec 2 07:19:11 CET 2018


Furquan Shaikh has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/30001


Change subject: mb/google/octopus: Enable mode change as wake source from S3/S0ix
......................................................................

mb/google/octopus: Enable mode change as wake source from S3/S0ix

This change enables mode change as a wake source from S3 and
S0ix. Thus, any time the device switches between clamshell and tablet
mode while it is suspended, it will be treated as a valid user event
and hence wake source.

BUG=b:120349473
BRANCH=octopus
TEST=Verified that octopus wakes up on mode transitions.

Change-Id: Ib224df434730f873ce5514303e5d043cbc85a9a4
Signed-off-by: Furquan Shaikh <furquan at google.com>
---
M src/mainboard/google/octopus/variants/baseboard/include/baseboard/ec.h
1 file changed, 9 insertions(+), 2 deletions(-)



  git pull ssh://review.coreboot.org:29418/coreboot refs/changes/01/30001/1

diff --git a/src/mainboard/google/octopus/variants/baseboard/include/baseboard/ec.h b/src/mainboard/google/octopus/variants/baseboard/include/baseboard/ec.h
index 3398875..d416673 100644
--- a/src/mainboard/google/octopus/variants/baseboard/include/baseboard/ec.h
+++ b/src/mainboard/google/octopus/variants/baseboard/include/baseboard/ec.h
@@ -43,10 +43,17 @@
 	(EC_HOST_EVENT_MASK(EC_HOST_EVENT_LID_OPEN)     |\
 	 EC_HOST_EVENT_MASK(EC_HOST_EVENT_POWER_BUTTON))
 
 /* EC can wake from S3 with lid or power button or key press */
 #define MAINBOARD_EC_S3_WAKE_EVENTS \
 	(MAINBOARD_EC_S5_WAKE_EVENTS |\
-	 EC_HOST_EVENT_MASK(EC_HOST_EVENT_KEY_PRESSED))
+	 EC_HOST_EVENT_MASK(EC_HOST_EVENT_KEY_PRESSED) |\
+	 EC_HOST_EVENT_MASK(EC_HOST_EVENT_MODE_CHANGE))
 
 #define MAINBOARD_EC_S0IX_WAKE_EVENTS	(MAINBOARD_EC_S3_WAKE_EVENTS)
 
@@ -43,10 +43,17 @@
 	 EC_HOST_EVENT_MASK(EC_HOST_EVENT_POWER_BUTTON))
 
-/* EC can wake from S3 with lid or power button or key press */
+/*
+ * EC can wake from S3/S0ix with:
+ * 1. Lid open
+ * 2. Power button
+ * 3. Key press
+ * 4. Mode change
+ */
 #define MAINBOARD_EC_S3_WAKE_EVENTS \
 	(MAINBOARD_EC_S5_WAKE_EVENTS |\

-- 
To view, visit https://review.coreboot.org/c/coreboot/+/30001
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings

Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: Ib224df434730f873ce5514303e5d043cbc85a9a4
Gerrit-Change-Number: 30001
Gerrit-PatchSet: 1
Gerrit-Owner: Furquan Shaikh <furquan at google.com>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://mail.coreboot.org/pipermail/coreboot-gerrit/attachments/20181202/486b8530/attachment.html>


More information about the coreboot-gerrit mailing list